/*
 * Copyright 2025 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.tooling.internal.protocol.events;

import org.jspecify.annotations.NullMarked;
import org.jspecify.annotations.Nullable;

import java.io.File;

/**
 * DO NOT CHANGE THIS INTERFACE. It is part of the cross-version protocol.
 *
 * This is a new message sent from Gradle 9.4.0 and newer with file attachment data.
 * Older clients (before 9.4.0) ignore this message.
 *
 * @since 9.4.0
 */
@NullMarked
public interface InternalTestMetadataEventVersion2 extends InternalProgressEvent {
    @Override
    InternalTestMetadataDescriptor getDescriptor();

    File getFile();

    @Nullable
    String getMediaType();
}
