/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.process.internal.worker.problem;

import org.gradle.api.problems.Problem;
import org.gradle.internal.operations.OperationIdentifier;
import org.jspecify.annotations.Nullable;

/**
 * Wire protocol used by the worker to report problems back to the daemon.
 */
public interface WorkerProblemProtocol {
    /**
     * Reports a problem emitted by the worker.
     *
     * @throws IllegalStateException if no problems service is currently bound on the daemon side
     */
    void reportProblem(Problem problem, @Nullable OperationIdentifier id);
}
