/*
 * Copyright 2025 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.testing.source;

import org.gradle.api.tasks.testing.source.FilePosition;
import org.jspecify.annotations.Nullable;

public class DefaultFilePosition implements FilePosition {

    private final int line;
    @Nullable
    private final Integer column;

    public DefaultFilePosition(int  line, @Nullable Integer column) {
        this.line = line;
        this.column = column;
    }

    @Override
    public int getLine() {
        return line;
    }

    @Override
    public @Nullable Integer getColumn() {
        return column;
    }
}
