/*
 * Copyright 2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.file;

/**
 * Visitor which can request a reproducible file order.
 *
 * @since 3.4
 */
public interface ReproducibleFileVisitor extends FileVisitor {
    /**
     * Whether the {@link FileVisitor} should receive the files in a reproducible order independent of the underlying file system.
     *
     * @return <code>true</code> if files should be walked in a reproducible order.
     */
    boolean isReproducibleFileOrder();
}
